@@ -1,5 +1,4 @@
 from django.contrib.auth.models import User
-from django.db import models
 from w.services.abstract_model_service import AbstractModelService
 from w import exceptions
 
@@ -16,9 +15,33 @@ class UserService(AbstractModelService):
             return cls.create(**attrs)
 
     @classmethod
-    def create(cls, **attrs) -> models.Model:
+    def create(cls, **attrs) -> User:
         return User.objects.create_user(**attrs)
 
+    @classmethod
+    def update(cls, instance: User, **attrs):
+        password = attrs.pop("password") if "password" in attrs else None
+        instance = super().update(instance, **attrs)
+        if password:
+            instance.set_password(password)
+            instance.save()
+        return instance
+
+    @classmethod
+    def add_group(cls, user: User, group_id):
+        user.groups.add(group_id)
+        return user
+
+    @classmethod
+    def remove_group(cls, user: User, group_id):
+        user.groups.remove(group_id)
+        return user
+
+    @classmethod
+    def clear_groups(cls, user: User):
+        user.groups.clear()
+        return user
+
     @classmethod
     def get_by_email(cls, email):
         """
