@@ -11,7 +11,7 @@ class AbstractService(ABC):
 
     @classmethod
     def clear(cls):
-        pass
+        pass  # is like an abstract class method
 
     @classmethod
     def _is_initialized(cls):
