@@ -3,6 +3,7 @@ import datetime
 
 import arrow
 from arrow import Arrow
+from dateutil.relativedelta import relativedelta
 
 from w.services.abstract_service import AbstractService
 
@@ -21,11 +22,13 @@ class DateService(AbstractService):
 
     # timezone if none
     _timezone = None
+    _locale = "en-us"
 
     @classmethod
     def clear(cls):
         super().clear()
         cls._timezone = None
+        cls._locale = "en-us"
 
     @classmethod
     def _get(cls, d, default_now=True) -> Arrow:
@@ -57,8 +60,8 @@ class DateService(AbstractService):
             str
         """
         if cls._timezone:
-            return cls._get(d).to(cls._timezone).format(date_format)
-        return cls._get(d).format(date_format)
+            return cls._get(d).to(cls._timezone).format(date_format, locale=cls._locale)
+        return cls._get(d).format(fmt=date_format, locale=cls._locale)
 
     @classmethod
     def set_timezone(cls, timezone):
@@ -70,6 +73,10 @@ class DateService(AbstractService):
         """
         cls._timezone = timezone
 
+    @classmethod
+    def set_locale(cls, locale: str = ""):
+        cls._locale = locale
+
     @staticmethod
     def get(d) -> Arrow:
         """
@@ -437,3 +444,36 @@ class DateService(AbstractService):
             return nb
 
         return nb * -1
+
+    @classmethod
+    def nb_years(cls, start, end):
+        """
+        Number of years between 2 dates
+        Args:
+            start(str|Arrow|datetime.datetime|datetime.date): start date
+            end(str|Arrow|datetime.datetime|datetime.date): end date
+
+        Returns:
+            number of years: int
+        """
+
+        start = cls._get(start, default_now=False)
+        end = cls._get(end, default_now=False)
+
+        delta = relativedelta(end.datetime, start.datetime)
+        return delta.years
+
+    @classmethod
+    def shift(cls, d, shifting_amount) -> Arrow:
+        """
+        Shift a date with the amount
+
+        Args:
+            d (str|Arrow|datetime.datetime|datetime.date): arrow date to shift from
+            shifting_amount (dict):  shifting amount (use {years: 1, months:-1})
+
+        Returns:
+            Arrow: shifted date
+        """
+        d = cls._get(d, default_now=False)
+        return d.shift(**shifting_amount)
