@@ -1,4 +1,7 @@
+import copy
+
 from w.services.abstract_service import AbstractService
+from mergedeep import merge
 
 
 class DictService(AbstractService):
@@ -50,3 +53,8 @@ class DictService(AbstractService):
         for old, new in remap_keys.items():
             remaped[new] = d[old]
         return remaped
+
+    @classmethod
+    def deep_merge(cls, dict1, dict2):
+        """Merge deeply dict2 with dict1"""
+        return merge(copy.deepcopy(dict1), dict2)
