@@ -12,7 +12,7 @@ from w.services.technical.list_service import ListService
 class ExcelService(AbstractService):
     @classmethod
     def is_excel(cls, filename):
-        """ Check if filename is excel (from extension) """
+        """Check if filename is excel (from extension)"""
         return FilesystemService.has_suffix(filename, [".xls", ".xlsx"])
 
     @classmethod
@@ -81,20 +81,54 @@ class ExcelService(AbstractService):
         sheet = wb[sheet_name] if sheet_name is not None else wb.active
 
         rows = sheet.iter_rows()
-        headers = [c.value.strip() if c.value else None for c in next(rows)]
-        for i, required_header in enumerate(mapping_columns.keys()):
-            if required_header != headers[i]:
-                headers = ListService.convert_elements_to_string(headers)
-                raise ValidationError(
-                    f"incorrect or missing header, "
-                    f"expected '{';'.join(list(mapping_columns.keys()))}' "
-                    f"got '{';'.join(headers)}'"
-                )
+        headers = [
+            c.value.strip() if c.value else f"None_{i}"
+            for i, c in enumerate(next(rows))
+        ]
+        final_headers, final_mapping = cls._get_final_headers_and_mapping(
+            headers, mapping_columns
+        )
         return [
             {
-                mapping_columns[headers[i]]: cell.value
+                final_mapping[final_headers[i]]: cell.value
                 for i, cell in enumerate(row)
-                if headers[i] in mapping_columns
+                # if final_headers[i] in final_mapping and cell.value is not None
+                if final_headers[i] in final_mapping
             }
             for row in rows
         ]
+
+    @classmethod
+    def _get_final_headers_and_mapping(
+        cls, headers: list, mapping_columns: dict
+    ) -> tuple:
+        """Compare excel headers to mapping columns
+        and return final headers and mapping"""
+        if len(headers) > len(mapping_columns):
+            mapping_columns = cls._fill_mapping_columns_with_headers(
+                headers, mapping_columns
+            )
+        else:
+            for i, required_header in enumerate(mapping_columns.keys()):
+                if required_header != headers[i]:
+                    headers = ListService.convert_elements_to_string(headers)
+                    raise ValidationError(
+                        f"incorrect or missing header, "
+                        f"expected '{';'.join(list(mapping_columns.keys()))}' "
+                        f"got '{';'.join(headers)}'"
+                    )
+        return headers, mapping_columns
+
+    @staticmethod
+    def _fill_mapping_columns_with_headers(
+        headers: list, mapping_columns: dict
+    ) -> dict:
+        """Treat the case where some headers are empty"""
+        new_mapping_column = {}
+        for i, header_name in enumerate(headers):
+            if header_name in mapping_columns.keys():
+                new_mapping_column[header_name] = mapping_columns[header_name]
+            else:
+                new_mapping_column[header_name] = f"None_{i}"
+
+        return new_mapping_column
