@@ -5,15 +5,19 @@ import urllib.error
 import urllib.parse
 import urllib.request
 from django.conf import settings
+import os
 
-API_KEY = settings.GOOGLE_MAP_SECRET
+from w.services.technical.json_service import JsonService
+from w.services.technical.request_service import RequestService
+
+API_KEY = str(os.getenv("GOOGLE_MAP_SECRET"))
+API_KEY_PLACE = str(os.getenv("GOOGLE_MAP_API_KEY"))
 GEOCODE_BASE_URL = "https://maps.googleapis.com/maps/api/geocode/json"
 AUTOCOMPLETE_BASE_URL = (
     "https://maps.googleapis.com/maps/api/place/queryautocomplete/json"
 )
 PLACE_DETAIL_URL = "https://maps.googleapis.com/maps/api/place/details/json"
-"""
-"""
+FIND_PLACE_URL = "https://maps.googleapis.com/maps/api/place/findplacefromtext/json"
 
 
 class GoogleMapService(AbstractService):
@@ -26,6 +30,32 @@ class GoogleMapService(AbstractService):
 
         return cls._loop_until_endpoint_is_reached(url, cls._parse_geocode_response)
 
+    @classmethod
+    def search_by_phone_number(cls, phone_number):
+        response = RequestService.get(
+            f"{FIND_PLACE_URL}?input=%2B33{phone_number}&inputtype=phonenumber"
+            f"&fields=place_id,"
+            f"name,formatted_address,type&key={API_KEY_PLACE}"
+        )
+        if response.success:
+            return response.content
+        cls._raise_api_failed(response, "Failed to get google place")
+
+    @classmethod
+    def _raise_api_failed(cls, response, msg):
+        """
+        raise RuntimeError for yousign api failure
+        """
+        if JsonService.is_valid(response.orig_content):
+            error = json.loads(response.orig_content)
+            error = error["detail"]
+        else:
+            error = "no detail"
+
+        raise RuntimeError(
+            f"{msg} ({response.status_code} - {response.content}) : {error}"
+        )
+
     @classmethod
     def autocomplete_address(cls, textual_address, session_token=None):
         if settings.MOCK_GMAP_CALLS:
