@@ -55,12 +55,7 @@ class YouSignRequest(DataclassMixin):
             "config": {
                 "email": {"member.started": [self.member_started_mail.to_dict()]},
                 "webhook": {
-                    "member.finished": [
-                        {
-                            "url": self.webhook_url,
-                            "method": "POST",
-                        }
-                    ]
+                    "member.finished": [{"url": self.webhook_url, "method": "POST"}]
                 },
             },
         }
