@@ -6,16 +6,18 @@ SSO={
     "REALM": <sso api realm>,
     "CLIENT_ID": <sso client id api>,
     "CLIENT_SECRET_KEY": <sso client secret see Client credentials>,
-    "ADMIN_LOGIN": <optional: sso admin user>
+    "ADMIN_SECRET_KEY": <optional: sso admin secret key>,
+    "ADMIN_LOGIN": <optional: sso admin user>,
     "ADMIN_PASSWORD": <optional: sso admin password>
 }
 """
 from typing import Optional
 
 from django.conf import settings
-from keycloak import KeycloakOpenID, KeycloakAdmin
+from keycloak import KeycloakOpenID, KeycloakAdmin, KeycloakAuthenticationError
 from rest_framework.exceptions import AuthenticationFailed
 
+from w import exceptions
 from w.services.abstract_service import AbstractService
 from django.utils.translation import gettext as _
 
@@ -24,6 +26,7 @@ from w.services.technical.models.sso import SsoValidToken
 
 class SsoService(AbstractService):
     _keycloak_session: KeycloakOpenID = None
+    _keyckloak_public_client_session: KeycloakOpenID = None
     _keycloak_admin: KeycloakAdmin = None
     _clients: Optional[dict] = None
     _client_roles: dict = {}
@@ -31,6 +34,7 @@ class SsoService(AbstractService):
     @classmethod
     def clear(cls):
         cls._keycloak_session = None
+        cls._keyckloak_public_client_session = None
         cls._keycloak_admin = None
         cls._clients = None
         cls._client_roles = {}
@@ -39,9 +43,15 @@ class SsoService(AbstractService):
     def _is_initialized(cls):
         return cls._keycloak_session is not None
 
+    @classmethod
+    def _has_admin_settings(cls):
+        return (
+            "ADMIN_SECRET_KEY" in settings.SSO and settings.SSO["ADMIN_SECRET_KEY"]
+        ) or ("ADMIN_LOGIN" in settings.SSO and "ADMIN_PASSWORD" in settings.SSO)
+
     @classmethod
     def _init_keycloak_admin(cls):
-        if "ADMIN_LOGIN" in settings.SSO and "ADMIN_PASSWORD" in settings.SSO:
+        if cls._has_admin_settings():
             cls._keycloak_admin = cls._get_keycloak_admin()
             return cls._keycloak_admin
 
@@ -52,15 +62,39 @@ class SsoService(AbstractService):
         cls._check_is_initialized()
         return cls._init_keycloak_admin()
 
+    @classmethod
+    def initialize_public_client(cls):
+        """Initialize public client
+        config(dict): Sso  configuration:
+            server_url(str): sso server url
+            realm_name(str): realm name
+            client_id(str): client id with public access type
+        """
+        config = {
+            "server_url": settings.SSO_PUBLIC_CLIENT["SERVER_URL"],
+            "realm_name": settings.SSO_PUBLIC_CLIENT["REALM"],
+            "client_id": settings.SSO_PUBLIC_CLIENT["CLIENT_ID"],
+        }
+        cls._keyckloak_public_client_session = KeycloakOpenID(**config)
+
     @classmethod
     def _get_keycloak_admin(cls):  # pragma: no cover
-        """Only to simplify tests"""
-        kc = KeycloakAdmin(
-            server_url=settings.SSO["SERVER_URL"],
-            username=settings.SSO["ADMIN_LOGIN"],
-            password=settings.SSO["ADMIN_PASSWORD"],
-            realm_name="master",
-        )
+        params = {
+            "server_url": settings.SSO["SERVER_URL"],
+            "realm_name": "master",
+        }
+        if "ADMIN_SECRET_KEY" in settings.SSO and settings.SSO["ADMIN_SECRET_KEY"]:
+            params = {
+                **params,
+                "client_secret_key": settings.SSO["ADMIN_SECRET_KEY"],
+            }
+        else:
+            params = {
+                **params,
+                "username": settings.SSO["ADMIN_LOGIN"],
+                "password": settings.SSO["ADMIN_PASSWORD"],
+            }
+        kc = KeycloakAdmin(**params)
         kc.realm_name = settings.SSO["REALM"]
         return kc
 
@@ -99,9 +133,22 @@ class SsoService(AbstractService):
         cls._check_is_initialized()
         decoded_token = cls._sso_introspect(token)
         if decoded_token.get("active", False):
-            return SsoValidToken(decoded_token)
+            return SsoValidToken(
+                decoded_token, list_roles=cls.list_user_roles(decoded_token["sub"])
+            )
         raise AuthenticationFailed(_("Invalid or expired token."))
 
+    @classmethod
+    def list_user_roles(cls, uuid):
+        cls._initialize_admin()
+        clients = cls._keycloak_admin.get_clients()
+        roles = []
+        for c in clients:
+            roles += cls._keycloak_admin.get_client_roles_of_user(
+                user_id=uuid, client_id=c["id"]
+            )
+        return roles
+
     @classmethod
     def create_user(cls, user: dict):
         # need client role: realm-management:manage-users
@@ -180,3 +227,14 @@ class SsoService(AbstractService):
             lifespan=lifespan,
             redirect_uri=redirect_uri,
         )
+
+    @classmethod
+    def _get_user_token(cls, username: str, password: str):  # pragma: no cover
+        return cls._keyckloak_public_client_session.token(username, password)
+
+    @classmethod
+    def check_user_credentials(cls, username: str, password: str):
+        try:
+            return cls._get_user_token(username, password)
+        except KeycloakAuthenticationError:
+            raise exceptions.InvalidCredentialsError()
