@@ -1,4 +1,5 @@
 from django.utils.http import urlencode
+import re
 
 from w.services.abstract_service import AbstractService
 
@@ -19,3 +20,15 @@ class UrlService(AbstractService):
             relative_url = f"/{relative_url}"
 
         return f"{base_url}{relative_url}"
+
+    @staticmethod
+    def is_valid_url(url: str) -> bool:
+        if (
+            re.match(
+                r"^[(http(s)?):\/\/(www\.)?a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,6}\b([-a-zA-Z0-9@:%_\+.~#?&\/\/=]*)$",  # noqa
+                url,
+            )
+            is not None
+        ):
+            return True
+        return False
