@@ -10,6 +10,11 @@ class SimpleCreateValidation(DrfValidatorSerializerMixin, serializers.Serializer
     date = serializers.DateField()
 
 
+class WithContextValidation(SimpleCreateValidation):
+    def validate_integer(self, value):
+        return value * self.context["factor"]
+
+
 class ExampleCreateValidation(DrfValidatorSerializerMixin, serializers.ModelSerializer):
     class Meta:
         model = models.ExampleWithInternalDependencies
