@@ -1,5 +1,7 @@
 from django.db import models
 
+from w.django.models import AbstractSsoUser
+
 
 class Example(models.Model):
     attribute_one = models.CharField(max_length=50)
@@ -53,3 +55,7 @@ class ExampleWithInternalDependencies(models.Model):
 
     def __str__(self):
         return f"{self.name} ({self.internal_one}/{self.internal_two})"
+
+
+class SsoUser(AbstractSsoUser):
+    pass
