@@ -70,6 +70,17 @@ def mock_request(responses, method="get"):
         yield m
 
 
+def _get_response_from_json(json_file, params):
+    with open(json_file) as f:
+        content = f.read()
+        if "reason" not in params:
+            params["content"] = content
+        else:
+            params["content"] = params["reason"]
+            params["orig_content"] = content
+    return RequestResponse(**params)
+
+
 def get_response(**params):
     """
     Get request response
@@ -87,7 +98,7 @@ def get_response(**params):
             }
 
     Returns:
-        list(RequestResponse): list of response
+        Union[RequestResponse,List[RequestResponse]]: response or list of responses (if json_file is list)
     """
     default_params = {
         "content": "some content",
@@ -107,18 +118,11 @@ def get_response(**params):
         return RequestResponse(**params)
 
     if not isinstance(params["json_file"], list):
-        params["json_file"] = (params["json_file"],)
+        return _get_response_from_json(params["json_file"], params)
 
     result = []
     for json_file in params["json_file"]:
-        with open(json_file) as f:
-            content = f.read()
-            if "reason" not in params:
-                params["content"] = content
-            else:
-                params["content"] = params["reason"]
-                params["orig_content"] = content
-            result.append(RequestResponse(**params))
+        result.append(_get_response_from_json(json_file, params))
     return result
 
 
