@@ -2,6 +2,7 @@ from contextlib import contextmanager
 from pathlib import Path
 from unittest.mock import Mock
 
+from keycloak import KeycloakAuthenticationError
 from w.services.technical.models.sso import SsoValidToken
 from w.services.technical.sso_service import SsoService
 from w.tests.helpers import service_test_helper
@@ -35,6 +36,18 @@ def _mock_get_or_create_user():
     }
 
 
+def _get_user_token_mock_attrs(dataset="valid_user_token"):
+    side_effect = (
+        KeycloakAuthenticationError() if dataset == "invalid_user_token" else None
+    )
+    return {
+        "service": SsoService,
+        "method_name": "_get_user_token",
+        "return_value": _get_dataset(f"sso/{dataset}.json"),
+        "side_effect": side_effect,
+    }
+
+
 @contextmanager
 def mock_keycloak_admin_init():
     keycloak_admin = Mock()
@@ -73,6 +86,20 @@ def sso_introspect_success():
         yield m
 
 
+@contextmanager
+def mock_invalid_user_token():
+    mock_attrs = _get_user_token_mock_attrs("invalid_user_token")
+    with service_test_helper.mock_service(**mock_attrs) as m:
+        yield m
+
+
+@contextmanager
+def mock_valid_user_token():
+    mock_attrs = _get_user_token_mock_attrs()
+    with service_test_helper.mock_service(**mock_attrs) as m:
+        yield m
+
+
 @contextmanager
 def valid_token_success(uuid="fake-uuid"):
     fake_decoded_token = {
@@ -87,10 +114,20 @@ def valid_token_success(uuid="fake-uuid"):
             }
         },
     }
+    list_roles = [
+        {
+            "id": "2833c19b-13f1-4367-b128-4c440323ad1d",
+            "name": "role_app1",
+            "description": "Role App1",
+            "composite": False,
+            "clientRole": True,
+            "containerId": "1a6113a1-2cfa-4f32-92c6-3359874104c0",
+        }
+    ]
     mock_attrs = {
         "service": SsoService,
         "method_name": "is_token_valid",
-        "return_value": SsoValidToken(fake_decoded_token),
+        "return_value": SsoValidToken(fake_decoded_token, list_roles=list_roles),
     }
     with service_test_helper.mock_service(**mock_attrs) as m:
         yield m
