@@ -49,7 +49,7 @@ class TestCaseMixin:
 
     @classmethod
     def get_base_dir(cls):
-        """ Get base dir from django settings by default """
+        """Get base dir from django settings by default"""
         if cls.base_dir is None:
             from django.conf import settings
 
@@ -58,7 +58,7 @@ class TestCaseMixin:
 
     @classmethod
     def get_tmp_dir(cls):
-        """ Get tmp test directory """
+        """Get tmp test directory"""
         return f"{cls.get_base_dir()}/.donotcommit_tmp"
 
     @classmethod
@@ -188,10 +188,39 @@ class TestCaseMixin:
         """
         return cls._get_dataset(dataset, cls.get_app_datasets_dir(dataset, app))
 
+    @classmethod
+    def _save_json_file_as_fixture(cls, fixture_filename, dataset):
+        new_json = cls._convert_dataset_to_json(dataset)
+        if fixture_filename.exists():
+            actual = fixture_filename.read_text()
+            if actual == new_json:
+                return None
+            else:
+                cls._check_file_can_be_created(fixture_filename)
+        fixture_filename.write_text(new_json)
+
+    @classmethod
+    def _save_bytes_file_as_fixture(cls, fixture_filename, dataset):
+        if fixture_filename.exists():
+            actual = fixture_filename.read_bytes()
+            if actual == dataset:
+                return None
+            else:
+                cls._check_file_can_be_created(fixture_filename)
+        fixture_filename.write_bytes(dataset)
+
     @classmethod
     def _save_as_fixture(cls, fixture_filename, dataset):
         fixture_filename = Path(fixture_filename)
-        new_json = (
+
+        if fixture_filename.suffix == ".json":
+            cls._save_json_file_as_fixture(fixture_filename, dataset)
+        else:
+            cls._save_bytes_file_as_fixture(fixture_filename, dataset)
+
+    @classmethod
+    def _convert_dataset_to_json(cls, dataset):
+        return (
             json.dumps(
                 cls._convert_data(dataset),
                 separators=(",", ": "),
@@ -202,17 +231,6 @@ class TestCaseMixin:
             + "\n"
         )  # for respecting file empty last line convention
 
-        if fixture_filename.exists():
-            # check if we need to update it
-            actual = fixture_filename.read_text()
-            if actual == new_json:
-                return None
-        else:
-            cls._check_file_can_be_created(fixture_filename)
-
-        # save dataset
-        fixture_filename.write_text(new_json)
-
     @classmethod
     def save_as_dataset(cls, relative_filename, dataset):
         fixture_filename = cls.get_datasets_dir(relative_filename)
