@@ -13,6 +13,10 @@ class TestDateService(TestCaseMixin):
     def setup_method():
         DateService.clear()
 
+    @classmethod
+    def teardown_class(cls):
+        DateService.clear()
+
     """
     previous_weekday
     """
@@ -211,11 +215,11 @@ class TestDateService(TestCaseMixin):
     """
 
     def test_is_week_end_with_date_outside_week_end_return_false(self):
-        """ Ensure date outside week end return False """
+        """Ensure date outside week end return False"""
         assert not DateService.is_week_end("2019-04-30")
 
     def test_is_week_end_with_date_inside_week_end_return_true(self):
-        """ Ensure date outside week end return False """
+        """Ensure date outside week end return False"""
         assert DateService.is_week_end("2019-04-27")
         assert DateService.is_week_end("2019-04-28")
 
@@ -251,3 +255,59 @@ class TestDateService(TestCaseMixin):
         """Ensure nb days succeed"""
         assert 4 == DateService.nb_days("2019-03-01", "2019-03-06", True)
         assert -6 == DateService.nb_days("2019-03-11", "2019-03-04", True)
+
+    """
+    nb_years
+    """
+
+    def test_nb_years_with_success_return_int(self):
+        """Ensure nb years succeed"""
+        assert 4 == DateService.nb_years("2015-03-01", "2019-03-06")
+        assert -3 == DateService.nb_years("2022-03-09", "2019-03-06")
+
+    """
+    shift
+    """
+
+    def test_shift_with_success_return_arrow(self):
+        """Ensure shift succeed"""
+        self.assert_equals_resultset(DateService.shift("2015-03-01", {"days": 4}))
+
+    def test_shift_with_multiple_params_return_arrow(self):
+        """Ensure shift succeed with multiple params"""
+        self.assert_equals_resultset(
+            DateService.shift("2015-03-01", {"days": 3, "months": 2})
+        )
+
+    def test_shift_with_bad_params_return_error(self):
+        """Ensure shift fails with bad params"""
+        with pytest.raises(ValueError) as e_info:
+            DateService.shift("2015-03-01", {"year": 3, "months": 2})
+        self.assert_equals_resultset(e_info)
+
+    """
+    to_str
+    """
+
+    def test_to_str_with_success_return_date_str(self):
+        expected = "18 March 2019 11:16:34"
+
+        with date_test_helper.today_is("2019-03-18T11:16:34.786+01:00"):
+            assert DateService.to_str(date_format="DD MMMM YYYY HH:mm:ss") == expected
+
+    def test_to_str_with_locale_return_date_str(self):
+        DateService.set_locale("fr-fr")
+
+        expected = "18 mars 2019 11:16:34"
+
+        with date_test_helper.today_is("2019-03-18T11:16:34.786+01:00"):
+            assert DateService.to_str(date_format="DD MMMM YYYY HH:mm:ss") == expected
+
+    def test_to_str_with_locale_and_timezone_return_date_str(self):
+        DateService.set_timezone("Europe/Paris")
+        DateService.set_locale("fr-fr")
+
+        expected = "19 mars 2019 00:18:36"
+
+        with date_test_helper.today_is("2019-03-18 23:18:36.224469"):
+            assert DateService.to_str(date_format="DD MMMM YYYY HH:mm:ss") == expected
