@@ -89,6 +89,5 @@ class TestPdfService(TestCaseMixin):
             "filename": self.get_sandbox_dir(filename=self.filename),
             "content": "<h1>test</h1>",
         }
-        pdf = PdfService.write_file(**params)
-        assert pdf is not None and isinstance(pdf, bytes)
+        assert PdfService.write_file(**params) is None
         self.assert_file_exists(params["filename"])
