@@ -3,6 +3,7 @@ from django.conf import settings
 from django.test.utils import override_settings
 from rest_framework.exceptions import AuthenticationFailed
 
+from w.exceptions import InvalidCredentialsError
 from w.services.technical.models.sso import SsoValidToken
 from w.services.technical.sso_service import SsoService
 from w.tests.helpers import sso_test_helper
@@ -49,13 +50,56 @@ class TestSsoService(TestCaseMixin):
 
     def test_token_is_valid_with_success_return_sso_token(self):
         """Ensure method succeed"""
-        with sso_test_helper.sso_introspect_success() as m:
+        self.keycloak_admin.get_clients.return_value = self.get_dataset(
+            "sso/get_clients_success.json"
+        )
+        self.keycloak_admin.get_client_roles_of_user.return_value = self.get_dataset(
+            "sso/get_client_roles.json"
+        )
+        with sso_test_helper.mock_keycloak_initialize_admin(), sso_test_helper.sso_introspect_success() as m:  # noqa
             actual = SsoService.is_token_valid("valid-token")
         assert isinstance(actual, SsoValidToken)
         self.assert_equals_resultset(
             {"actual": actual.to_dict(), "mock_calls": self.get_mock_calls(m)}
         )
 
+    """
+    list_user_roles
+    """
+
+    def test_list_user_roles_with_not_initialize_service_raise_runtime_error(self):
+        """Ensure method raise RuntimeError if service is not initialized"""
+        SsoService.clear()
+        match = "Service SsoService must be initialized first"
+        with pytest.raises(RuntimeError, match=match):
+            SsoService.list_user_roles("ee2fa73a-2a46-41e9-a844-5f9a5cff742a")
+
+    def test_list_user_roles_with_missing_admin_raise_error(self):
+        """Ensure method raise RuntimeError if not initialized"""
+        SsoService.clear()
+        sso_settings = {**settings.SSO}
+        sso_settings.pop("ADMIN_PASSWORD")
+        SsoService.init()
+
+        match = "Missing SSO settings ADMIN_LOGIN or ADMIN_PASSWORD"
+        with override_settings(SSO=sso_settings):
+            with pytest.raises(RuntimeError, match=match):
+                SsoService.list_user_roles("ee2fa73a-2a46-41e9-a844-5f9a5cff742a")
+
+    def test_list_user_roles_with_success_return_dict(self):
+        """Ensure method succeeds"""
+        self.keycloak_admin.get_clients.return_value = self.get_dataset(
+            "sso/get_clients_success.json"
+        )
+        self.keycloak_admin.get_client_roles_of_user.return_value = self.get_dataset(
+            "sso/get_client_roles.json"
+        )
+        with sso_test_helper.mock_keycloak_initialize_admin():
+            actual = SsoService.list_user_roles("ee2fa73a-2a46-41e9-a844-5f9a5cff742a")
+        self.assert_equals_resultset(
+            {"actual": actual, "mocks": self.get_mock_calls(self.keycloak_admin)}
+        )
+
     """
     get_clients
     """
@@ -156,3 +200,30 @@ class TestSsoService(TestCaseMixin):
         self.assert_equals_resultset(
             {"actual": actual, "mocks": self.get_mock_calls(self.keycloak_admin)}
         )
+
+    """
+    check_user_credentials
+    """
+
+    def test_check_user_credentials_with_invalid_credentials_raise_invalid_credentials_error(  # noqa
+        self,
+    ):
+        """Ensure method raise InvalidCredentialsError if credentials is invalid"""
+        match = "401 - Invalid Credentials"
+        with sso_test_helper.mock_invalid_user_token():
+            with pytest.raises(InvalidCredentialsError, match=match):
+                SsoService.check_user_credentials(
+                    self.user_data["username"], self.user_data["password"]
+                )
+
+    def test_check_user_credentials_with_valid_credentials_return_access_token(  # noqa
+        self,
+    ):
+        """Ensure method return access token if credentials is valid"""
+        with sso_test_helper.mock_valid_user_token() as m:
+            actual = SsoService.check_user_credentials(
+                self.user_data["username"], self.user_data["password"]
+            )
+        self.assert_equals_resultset(
+            {"actual": actual, "mocks": self.get_mock_calls(m)}
+        )
