@@ -36,14 +36,14 @@ class TestYouSignService(TestCaseMixin):
     """
 
     def test_create_with_service_not_initialized_raise_runtime_error(self):
-        """ Ensure method raise RuntimeError if service is not initialized """
+        """Ensure method raise RuntimeError if service is not initialized"""
         YouSignService.clear()
         match = "Service YouSignService must be initialized first"
         with pytest.raises(RuntimeError, match=match):
             YouSignService.create(self.yousign_request)
 
     def test_create_with_file_not_found_raise_runtime_error(self):
-        """ Ensure method raise RuntimeError if file does not exists """
+        """Ensure method raise RuntimeError if file does not exists"""
         # copy valid yousign request
         wrong_request = YouSignRequest(**self.yousign_request.to_dict())
         wrong_request.filename = "unknown.pdf"
@@ -52,7 +52,7 @@ class TestYouSignService(TestCaseMixin):
             YouSignService.create(wrong_request)
 
     def test_create_with_failed_upload_raise_runtime_error(self):
-        """ Ensure method raise """
+        """Ensure method raise"""
         response = {
             "json_file": self.get_datasets_dir("yousign/files_bad_request.json"),
         }
@@ -66,12 +66,15 @@ class TestYouSignService(TestCaseMixin):
                 YouSignService.create(self.yousign_request)
 
     def test_create_with_failed_create_procedure_raise_runtime_error(self):
-        """ Ensure method raise RuntimeError """
-        responses = request_test_helper.get_response(
-            json_file=self.get_datasets_dir("yousign/files_success.json")
-        ) + request_test_helper.get_400_response(
-            json_file=self.get_datasets_dir("yousign/procedures_bad_request.json")
-        )
+        """Ensure method raise RuntimeError"""
+        responses = [
+            request_test_helper.get_response(
+                json_file=self.get_datasets_dir("yousign/files_success.json")
+            ),
+            request_test_helper.get_400_response(
+                json_file=self.get_datasets_dir("yousign/procedures_bad_request.json")
+            ),
+        ]
 
         match = "Failed to create procedure .*"
         with request_test_helper.mock_request(responses, method="post"):
@@ -79,7 +82,7 @@ class TestYouSignService(TestCaseMixin):
                 YouSignService.create(self.yousign_request)
 
     def test_create_with_success_return_dict(self):
-        """ Ensure method succeed """
+        """Ensure method succeed"""
         response = {
             "json_file": [
                 self.get_datasets_dir("yousign/files_success.json"),
@@ -97,14 +100,14 @@ class TestYouSignService(TestCaseMixin):
     """
 
     def test_get_file_with_service_not_initialized_raise_runtime_error(self):
-        """ Ensure method raise RuntimeError if service is not initialized """
+        """Ensure method raise RuntimeError if service is not initialized"""
         YouSignService.clear()
         match = "Service YouSignService must be initialized first"
         with pytest.raises(RuntimeError, match=match):
             YouSignService.get_file(self.fake_file_id)
 
     def test_get_file_with_file_not_found_raise_runtime_error(self):
-        """ Ensure method raise RuntimeError if file does not exists """
+        """Ensure method raise RuntimeError if file does not exists"""
         # copy valid yousign request
         match = "Failed to get contract file"
         response = {
@@ -115,7 +118,7 @@ class TestYouSignService(TestCaseMixin):
                 YouSignService.get_file(self.fake_file_id)
 
     def test_get_file_with_success_return_base64(self):
-        """ Ensure method succeed """
+        """Ensure method succeed"""
         response = {
             "json_file": [
                 self.get_datasets_dir("yousign/files_base64_response"),
